[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Fuyu
![FUYU](/architecture.png)
A implementation of Fuyu from Adept in pytorch using Zeta primitives


[Blog paper code](https://www.adept.ai/blog/fuyu-8b)

# Appreciation
* Lucidrains
* Agorians
* Adept

# Install
`pip install fuyu`

## Usage
```python


```

# Architecture
image patch embeddings -> linear projection -> decoder llm



# License
MIT

# Citations

